@@ -23,25 +23,30 @@ from .type_defs import (
     DescribeICD10CMInferenceJobResponseTypeDef,
     DescribePHIDetectionJobResponseTypeDef,
     DescribeRxNormInferenceJobResponseTypeDef,
+    DescribeSNOMEDCTInferenceJobResponseTypeDef,
     DetectEntitiesResponseTypeDef,
     DetectEntitiesV2ResponseTypeDef,
     DetectPHIResponseTypeDef,
     InferICD10CMResponseTypeDef,
     InferRxNormResponseTypeDef,
+    InferSNOMEDCTResponseTypeDef,
     InputDataConfigTypeDef,
     ListEntitiesDetectionV2JobsResponseTypeDef,
     ListICD10CMInferenceJobsResponseTypeDef,
     ListPHIDetectionJobsResponseTypeDef,
     ListRxNormInferenceJobsResponseTypeDef,
+    ListSNOMEDCTInferenceJobsResponseTypeDef,
     OutputDataConfigTypeDef,
     StartEntitiesDetectionV2JobResponseTypeDef,
     StartICD10CMInferenceJobResponseTypeDef,
     StartPHIDetectionJobResponseTypeDef,
     StartRxNormInferenceJobResponseTypeDef,
+    StartSNOMEDCTInferenceJobResponseTypeDef,
     StopEntitiesDetectionV2JobResponseTypeDef,
     StopICD10CMInferenceJobResponseTypeDef,
     StopPHIDetectionJobResponseTypeDef,
     StopRxNormInferenceJobResponseTypeDef,
+    StopSNOMEDCTInferenceJobResponseTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -75,7 +80,7 @@ class Exceptions:
 
 class ComprehendMedicalClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html)
     """
 
@@ -91,7 +96,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#can_paginate)
         """
 
@@ -101,7 +106,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with a medical entities detection job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_entities_detection_v2_job)
         """
 
@@ -111,7 +116,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with an InferICD10CM job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_icd10_cm_inference_job)
         """
 
@@ -120,7 +125,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with a protected health information (PHI)
         detection job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_phi_detection_job)
         """
 
@@ -130,15 +135,25 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets the properties associated with an InferRxNorm job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_rx_norm_inference_job)
         """
 
+    def describe_snomedct_inference_job(
+        self, *, JobId: str
+    ) -> DescribeSNOMEDCTInferenceJobResponseTypeDef:
+        """
+        Gets the properties associated with an InferSNOMEDCT job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_snomedct_inference_job)
+        """
+
     def detect_entities(self, *, Text: str) -> DetectEntitiesResponseTypeDef:
         """
         The `DetectEntities` operation is deprecated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities)
         """
 
@@ -148,7 +163,7 @@ class ComprehendMedicalClient(BaseClient):
         specific information about them such as entity category, location, and
         confidence score on that information.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities_v2)
         """
 
@@ -157,7 +172,7 @@ class ComprehendMedicalClient(BaseClient):
         Inspects the clinical text for protected health information (PHI) entities and
         returns the entity category, location, and confidence score for each entity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_phi)
         """
 
@@ -171,7 +186,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#generate_presigned_url)
         """
 
@@ -181,7 +196,7 @@ class ComprehendMedicalClient(BaseClient):
         and links those entities to normalized concept identifiers in the ICD-10-CM
         knowledge base from the Centers for Disease Control.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_icd10_cm)
         """
 
@@ -191,10 +206,22 @@ class ComprehendMedicalClient(BaseClient):
         to the normalized concept identifiers in the RxNorm database from the National
         Library of Medicine.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_rx_norm)
         """
 
+    def infer_snomedct(self, *, Text: str) -> InferSNOMEDCTResponseTypeDef:
+        """
+        InferSNOMEDCT detects possible medical concepts as entities and links them to
+        codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT)
+        ontology See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/comprehendmedical-2018-10-30/InferSNOMEDCT)
+        **Re...
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_snomedct)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_snomedct)
+        """
+
     def list_entities_detection_v2_jobs(
         self,
         *,
@@ -205,7 +232,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of medical entity detection jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_entities_detection_v2_jobs)
         """
 
@@ -219,7 +246,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of InferICD10CM jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_icd10_cm_inference_jobs)
         """
 
@@ -234,7 +261,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of protected health information (PHI) detection jobs that you have
         submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_phi_detection_jobs)
         """
 
@@ -248,10 +275,24 @@ class ComprehendMedicalClient(BaseClient):
         """
         Gets a list of InferRxNorm jobs that you have submitted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_rx_norm_inference_jobs)
         """
 
+    def list_snomedct_inference_jobs(
+        self,
+        *,
+        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
+    ) -> ListSNOMEDCTInferenceJobsResponseTypeDef:
+        """
+        Gets a list of InferSNOMEDCT jobs a user has submitted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_snomedct_inference_jobs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_snomedct_inference_jobs)
+        """
+
     def start_entities_detection_v2_job(
         self,
         *,
@@ -267,7 +308,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous medical entity detection job for a collection of
         documents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_entities_detection_v2_job)
         """
 
@@ -286,7 +327,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous job to detect medical conditions and link them to the
         ICD-10-CM ontology.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_icd10_cm_inference_job)
         """
 
@@ -304,7 +345,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Starts an asynchronous job to detect protected health information (PHI).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_phi_detection_job)
         """
 
@@ -323,17 +364,36 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous job to detect medication entities and link them to the
         RxNorm ontology.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_rx_norm_inference_job)
         """
 
+    def start_snomedct_inference_job(
+        self,
+        *,
+        InputDataConfig: "InputDataConfigTypeDef",
+        OutputDataConfig: "OutputDataConfigTypeDef",
+        DataAccessRoleArn: str,
+        LanguageCode: Literal["en"],
+        JobName: str = ...,
+        ClientRequestToken: str = ...,
+        KMSKey: str = ...
+    ) -> StartSNOMEDCTInferenceJobResponseTypeDef:
+        """
+        Starts an asynchronous job to detect medical concepts and link them to the
+        SNOMED-CT ontology.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_snomedct_inference_job)
+        """
+
     def stop_entities_detection_v2_job(
         self, *, JobId: str
     ) -> StopEntitiesDetectionV2JobResponseTypeDef:
         """
         Stops a medical entities detection job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_entities_detection_v2_job)
         """
 
@@ -341,7 +401,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops an InferICD10CM inference job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_icd10_cm_inference_job)
         """
 
@@ -349,7 +409,7 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops a protected health information (PHI) detection job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_phi_detection_job)
         """
 
@@ -357,6 +417,14 @@ class ComprehendMedicalClient(BaseClient):
         """
         Stops an InferRxNorm inference job in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_rx_norm_inference_job)
         """
+
+    def stop_snomedct_inference_job(self, *, JobId: str) -> StopSNOMEDCTInferenceJobResponseTypeDef:
+        """
+        Stops an InferSNOMEDCT inference job in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_snomedct_inference_job)
+        """
